abacusai.api_class.monitor — AbacusAI documentation

# abacusai.api_class.monitor

## Classes

`TimeWindowConfig` | Time Window Configuration
`ForecastingMonitorConfig` | Forecasting Monitor Configuration
`StdDevThreshold` | Std Dev Threshold types
`ItemAttributesStdDevThreshold` | Item Attributes Std Dev Threshold for Monitor Alerts
`RestrictFeatureMappings` | Restrict Feature Mappings for Monitor Filtering
`MonitorFilteringConfig` | Monitor Filtering Configuration

## Module Contents

class abacusai.api_class.monitor.TimeWindowConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Time Window Configuration

  Parameters:

    - window_duration (int) – The duration of the window.

    - window_from_start (bool) – Whether the window should be from the start of the time series.

  window_duration: int = None
  window_from_start: bool = None
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.monitor.ForecastingMonitorConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Forecasting Monitor Configuration

  Parameters:

    - id_column (str) – The name of the column that contains the unique identifier for the time series.

    - timestamp_column (str) – The name of the column that contains the timestamp for the time series.

    - target_column (str) – The name of the column that contains the target value for the time series.

    - start_time (str) – The start time of the time series data.

    - end_time (str) – The end time of the time series data.

    - window_config (TimeWindowConfig) – The windowing configuration for the time series data.

  id_column: str = None
  timestamp_column: str = None
  target_column: str = None
  start_time: str = None
  end_time: str = None
  window_config: TimeWindowConfig = None
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.monitor.StdDevThreshold

  Bases: `abacusai.api_class.abstract.ApiClass`

  Std Dev Threshold types

  Parameters:

    - threshold_type (StdDevThresholdType) – Type of threshold to apply to the item attributes.

    - value (float) – Value to use for the threshold.

  threshold_type: abacusai.api_class.enums.StdDevThresholdType = None
  value: float = None
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.monitor.ItemAttributesStdDevThreshold

  Bases: `abacusai.api_class.abstract.ApiClass`

  Item Attributes Std Dev Threshold for Monitor Alerts

  Parameters:

    - lower_bound (StdDevThreshold) – Lower bound for the item attributes.

    - upper_bound (StdDevThreshold) – Upper bound for the item attributes.

  lower_bound: StdDevThreshold = None
  upper_bound: StdDevThreshold = None
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.monitor.RestrictFeatureMappings

  Bases: `abacusai.api_class.abstract.ApiClass`

  Restrict Feature Mappings for Monitor Filtering

  Parameters:

    - feature_name (str) – The name of the feature to restrict the monitor to.

    - restricted_feature_values (list) – The values of the feature to restrict the monitor to if feature is a categorical.

    - start_time (str) – The start time of the timestamp feature to filter from

    - end_time (str) – The end time of the timestamp feature to filter until

    - min_value (float) – Value to filter the numerical feature above

    - max_value (float) – Filtering the numerical feature to below this value

  feature_name: str = None
  restricted_feature_values: list = []
  start_time: str = None
  end_time: str = None
  min_value: float = None
  max_value: float = None
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.monitor.MonitorFilteringConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Monitor Filtering Configuration

  Parameters:

    - start_time (str) – The start time of the prediction time col

    - end_time (str) – The end time of the prediction time col

    - restrict_feature_mappings (RestrictFeatureMappings) – The feature mapping to restrict the monitor to.

    - target_class (str) – The target class to restrict the monitor to.

    - train_target_feature (str) – Set the target feature for the training data.

    - prediction_target_feature (str) – Set the target feature for the prediction data.

  start_time: str = None
  end_time: str = None
  restrict_feature_mappings: List[RestrictFeatureMappings] = None
  target_class: str = None
  train_target_feature: str = None
  prediction_target_feature: str = None
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.